@@ -34,10 +34,9 @@
 # -----------------------------------------------------------------------------
 
 """All the models including the schema as well as graph models"""
+from dataclasses import dataclass
 from typing import Any, Dict, List, Literal, Optional, TypedDict, Union
 
-from pydantic.dataclasses import dataclass
-
 from devinstaller_core.module_app import ModuleApp
 from devinstaller_core.module_file import ModuleFile
 from devinstaller_core.module_folder import ModuleFolder
@@ -157,6 +156,19 @@ class TypeValidateResponse(TypedDict):
     errors: Dict[Any, Any]
 
 
+TypeMethod = Literal["file", "url", "data"]
+
+
+@dataclass
+class TypeCheckPathResponse:
+    """Type declaration for the response of the
+    `devinstaller.file_manager.DevFileManager.check_path` method
+    """
+
+    method: TypeMethod
+    path: str
+
+
 TypeAnyModule = Union[
     ModuleApp, ModuleFile, ModuleFolder, ModuleLink, ModuleGroup, ModulePhony
 ]
